@@ -6,10 +6,11 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-__version__ = '0.1.8'
+__version__ = '0.1.10'
 
 #TODOS :
 #* Fix Identi.ca oauth bug
+#* Add separate notification for dm and mention
 #* Implements Twitpic
 #* Push 0.1.x line to extras
 #* Refactoring, Clean and Comment the code
@@ -284,6 +285,7 @@ class KhweeteurWin(QMainWindow):
             self.settings.setValue('twitter_access_token',1)
         else:
             self.settings.setValue('twitter_access_token',0)
+            
         if self.settings.value('identica_access_token') in ('True','1'):
             self.settings.setValue('identica_access_token',1)
         else:
@@ -365,6 +367,9 @@ class KhweeteurWin(QMainWindow):
                              )) * 60 * 1000)
 
         if not self.search_keyword:
+            if not (bool(self.settings.value('twitter_access_token')) or \
+                bool(self.settings.value('identica_access_token'))):
+                self.notifications.warn('Khweeteur aren\'t authorized to connect to any service. Please authorize one in preferences.')
             self.open_saved_search()
 
     def enterEvent(self, event):
@@ -533,8 +538,6 @@ class KhweeteurWin(QMainWindow):
             self.tb_text_replysource = self.tweetsModel.data(index,
                     role=ORIGINROLE)
 
-#            print self.tb_text_replysource, self.tb_text_replyid, self.tweetsModel._items[index.row()][3]
-
     @pyqtSlot()
     def open_url(self):
         import re
@@ -647,8 +650,6 @@ class KhweeteurWin(QMainWindow):
                         QMessageBox.Yes | QMessageBox.Close) \
                     == QMessageBox.Yes:
 
-                    # print 'DEBUG Follow:', user_screenname
-
                     if 'twitter' in self.tweetsModel.data(index,
                             role=ORIGINROLE):
                         try:
